NAME

Permute::Unnamed - Permute multiple-valued lists

VERSION

This document describes version 0.001 of Permute::Unnamed (from Perl distribution Permute-Unnamed), released on 2026-02-21.

SYNOPSIS

use Permute::Unnamed;

my @p = permute_unnamed([ 0, 1 ], [qw(foo bar baz)]);
# => (
#   [0, "foo"],
#   [0, "bar"],
#   [0, "baz"],
#   [1, "foo"],
#   [1, "bar"],
#   [1, "baz"],
# )

DESCRIPTION

This module is like Set::CrossProduct, except that it allows only a single argument.

FUNCTIONS

permute_unnamed(@list) => @list | $arrayref

HOMEPAGE

Please visit the project's homepage at https://metacpan.org/release/Permute-Unnamed.

SOURCE

Source repository is at https://github.com/perlancar/perl-Permute-Unnamed.

SEE ALSO

Set::CrossProduct

Permute::Named, PERLANCAR::Permute::Named, Permute::Named::Iter

AUTHOR

perlancar <perlancar@cpan.org>

CONTRIBUTING

To contribute, you can send patches by email/via RT, or send pull requests on GitHub.

Most of the time, you don't need to build the distribution yourself. You can simply modify the code, then test via:

% prove -l

If you want to build the distribution (e.g. to try to install it locally on your system), you can install Dist::Zilla, Dist::Zilla::PluginBundle::Author::PERLANCAR, Pod::Weaver::PluginBundle::Author::PERLANCAR, and sometimes one or two other Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond that are considered a bug and can be reported to me.

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.

BUGS

Please report any bugs or feature requests on the bugtracker website https://rt.cpan.org/Public/Dist/Display.html?Name=Permute-Unnamed

When submitting a bug or request, please include a test-file or a patch to an existing test-file that illustrates the bug or desired feature.